pub struct LogContext {
pub local: LogFields,
pub inherited: LogFields,
}Expand description
A set of fields that can be attached to a logging scope.
Fields are split into two categories:
- local - fields belonging only to the current scope. They do not propagate to child scopes.
- inherited - fields that automatically flow into all child scopes created within the current scope.
Nested scopes resolution rules:
- child
inheritedoverwrites parentinheritedby key - inherited are emitted before local, so “last write wins” consumers see local shadowing
Fields
local: LogFieldsFields belonging only to the current scope.
inherited: LogFieldsFields that automatically flow into all child scopes created within the current scope.
Implementations
Sourceimpl LogContext
impl LogContext
Sourcepub fn with_local_field(
self,
key: impl Into<Cow<'static, str>>,
value: impl Into<LogValue>,
) -> Self
pub fn with_local_field( self, key: impl Into<Cow<'static, str>>, value: impl Into<LogValue>, ) -> Self
Adds a key-value field to the local fields of this context.
See LogFields for more details about log fields.