pub struct LogContext {
pub local: LogRecords,
pub inherited: LogRecords,
}Expand description
A set of records that can be attached to a logging scope.
Records are split into two categories:
- local - records belonging only to the current scope. They do not propagate to child scopes.
- inherited - records that automatically flow into all child scopes created within the current scope.
Nested scopes resolution rules:
- child
inheritedoverwrites parentinheritedby key - inherited are emitted before local, so “last write wins” consumers see local shadowing
Fields
local: LogRecordsRecords belonging only to the current scope.
inherited: LogRecordsRecords that automatically flow into all child scopes created within the current scope.
Implementations
Sourceimpl LogContext
impl LogContext
Sourcepub fn with_local_record(
self,
key: impl Into<Cow<'static, str>>,
value: impl Into<LogValue>,
) -> Self
pub fn with_local_record( self, key: impl Into<Cow<'static, str>>, value: impl Into<LogValue>, ) -> Self
Adds a key-value record to the local records of this context.
See LogRecords for more details about log records.
Sourcepub fn with_inherited_record(
self,
key: impl Into<Cow<'static, str>>,
value: impl Into<LogValue>,
) -> Self
pub fn with_inherited_record( self, key: impl Into<Cow<'static, str>>, value: impl Into<LogValue>, ) -> Self
Adds a key-value record to the inherited records of this context.
See LogRecords for more details about log records.